Struct SubBuffer

pub(crate) struct SubBuffer<T> {
    pub(crate) buffer: T,
    pub(crate) buffer_size: Vec2D<u32>,
    pub(crate) offset: Vec2D<u32>,
    pub(crate) size: Vec2D<u32>,
}
A sub-region of an image, represented as a buffer with bounds. This struct allows for accessing and modifying a subsection of the image efficiently.

Fields

buffer: T

The underlying image buffer.

buffer_size: Vec2D<u32>

The size of the entire buffer in pixels.

offset: Vec2D<u32>

The offset of this sub-buffer within the overall buffer.

size: Vec2D<u32>

The dimensions of the sub-buffer.